from redpepper.manager.manager import AgentConnection
from redpepper.requests import RequestError


def call(conn: AgentConnection, **kwargs):
    raise RequestError("This is a no-op template request module.")


call.__qualname__ = "request noop"



import base64
import os
from typing import BinaryIO

from redpepper.manager.manager import AgentConnection
from redpepper.requests import RequestError


def call(conn: AgentConnection, name: str, existing_mtime: float, existing_size: int):
    try:
        path = conn.manager.data_manager.get_operation_module_path(name)
    except ValueError as e:
        raise RequestError(str(e)) from e
    try:
        stat = os.stat(path)
        mtime = stat.st_mtime
        size = stat.st_size
        if mtime == existing_mtime and size == existing_size:
            return {"changed": False}
    except FileNotFoundError as e:
        raise RequestError(f"Operation module not found: {name}") from e
    with open(path, "rb") as f:
        f: BinaryIO
        mtime = os.fstat(f.fileno()).st_mtime
        data = f.read()
    if len(data) > 32 * 1024:
        raise RequestError(f"Operation module too large: {name}")
    return {
        "changed": True,
        "content": base64.b64encode(data).decode("utf-8"),
        "mtime": mtime,
        "size": len(data),
    }


call.__qualname__ = "request operationModule"



import base64

from redpepper.manager.manager import AgentConnection
from redpepper.requests import RequestError


def call(conn: AgentConnection, filename: str, offset: int, length: int):
    try:
        path = conn.manager.data_manager.get_data_file_path(conn.agent_id, filename)
    except ValueError as e:
        raise RequestError(str(e)) from e
    except FileNotFoundError:
        raise RequestError(f"File not found: {filename}")
    try:
        with open(path, "rb") as f:
            f.seek(offset)
            data = f.read(length)
    except FileNotFoundError as e:
        raise RequestError(f"File not found: {filename}") from e
    return base64.b64encode(data).decode("utf-8")


call.__qualname__ = "request dataFileContents"



from redpepper.manager.manager import AgentConnection
from redpepper.requests import RequestError


def call(conn: AgentConnection, name: str):
    try:
        return conn.manager.data_manager.get_data_for_agent(conn.agent_id, name)
    except KeyError:
        raise RequestError(f"Data not found: {name}")


call.__qualname__ = "request data"



import os

from redpepper.manager.manager import AgentConnection
from redpepper.requests import RequestError


def call(conn: AgentConnection, path: str):
    try:
        fullpath = conn.manager.data_manager.get_data_file_path(conn.agent_id, path)
    except ValueError as e:
        raise RequestError(str(e)) from e
    except FileNotFoundError:
        raise RequestError(f"File not found: {path}")
    try:
        stat = os.stat(fullpath)
        mtime = stat.st_mtime
        size = stat.st_size
    except FileNotFoundError:
        raise RequestError(f"File not found: {path}")
    return {
        "mtime": mtime,
        "size": size,
    }


call.__qualname__ = "request dataFileStat"



from redpepper.manager.manager import AgentConnection
from redpepper.requests import RequestError


def call(conn: AgentConnection, state_name: str | None = None):
    try:
        state = conn.manager.data_manager.get_state_definition_for_agent(
            conn.agent_id, state_name
        )
    except ValueError as e:
        raise RequestError(str(e)) from e
    return state


call.__qualname__ = "request stateDefinition"



import hashlib
from typing import BinaryIO

from redpepper.manager.manager import AgentConnection
from redpepper.requests import RequestError


def call(conn: AgentConnection, path: str):
    try:
        fullpath = conn.manager.data_manager.get_data_file_path(conn.agent_id, path)
    except ValueError as e:
        raise RequestError(str(e)) from e
    except FileNotFoundError:
        raise RequestError(f"File not found: {path}")
    try:
        hash = hashlib.sha256()
        with open(fullpath, "rb") as f:
            f: BinaryIO
            for chunk in iter(lambda: f.read(4096), b""):
                hash.update(chunk)
    except FileNotFoundError:
        raise RequestError(f"File not found: {path}")
    return hash.hexdigest()


call.__qualname__ = "request dataFileHash"
